@@ -1,14 +1,14 @@
 /*
  * This file is part of btag.
  *
- * © 2010 Fernando Tarlá Cardoso Lemos
+ * © 2010-2011 Fernando Tarlá Cardoso Lemos
  *
  * Refer to the LICENSE file for licensing information.
  *
  */
 
-#ifndef CONSERVATIVE_RENAMING_FILTER
-#define CONSERVATIVE_RENAMING_FILTER
+#ifndef CONSERVATIVE_RENAMING_FILTER_H
+#define CONSERVATIVE_RENAMING_FILTER_H
 
 #include "RenamingFilter.h"
 
@@ -21,11 +21,11 @@ class ConservativeRenamingFilter : public RenamingFilter
             if (c >= L'A' && c <= L'Z') return true;
             if (c >= L'0' && c <= L'9') return true;
 
-            static wchar_t allowed_chars[15] = {
+            static wchar_t allowed_chars[] = {
                 L' ', L'%', L'-', L'_', L'@', L'~', L'`', L'!',
-                L'(', L')', L'{', L'}', L'^', L'#', L'&',
+                L'(', L')', L'{', L'}', L'^', L'#', L'&', L'.'
             };
-            for (int i = 0; i < 15; ++i) {
+            for (unsigned int i = 0; i < sizeof(allowed_chars) / sizeof(wchar_t); ++i) {
                 if (c == allowed_chars[i])
                     return true;
             }
